save_beast_estimates: Save the BEAST2 estimates as a BEAST2 '.log' file There will...

View source: R/save_beast_estimates.R

save_beast_estimatesR Documentation

Save the BEAST2 estimates as a BEAST2 .log file There will be some differences: a BEAST2 .log file also saves the model as comments and formats the numbers in a way non-standard to R

Description

Save the BEAST2 estimates as a BEAST2 .log file There will be some differences: a BEAST2 .log file also saves the model as comments and formats the numbers in a way non-standard to R

Usage

save_beast_estimates(estimates, filename)

Arguments

estimates

a data frame of BEAST2 parameter estimates

filename

name of the .log file to save to

Value

nothing

Author(s)

Richèl J.C. Bilderbeek

See Also

Use parse_beast_log to read a BEAST2 .log file


tracerer documentation built on March 2, 2026, 5:07 p.m.