save_beast_trees: Save the BEAST2 trees as a BEAST2 '.log' file There will be...

View source: R/save_beast_trees.R

save_beast_treesR Documentation

Save the BEAST2 trees as a BEAST2 .log file There will be some differences: a BEAST2 .log file also saves the model as comments and formats the numbers in a way non-standard to R

Description

Save the BEAST2 trees as a BEAST2 .log file There will be some differences: a BEAST2 .log file also saves the model as comments and formats the numbers in a way non-standard to R

Usage

save_beast_trees(trees, filename)

Arguments

trees

BEAST2 posterior trees, of type ape::multiPhylo

filename

name of the .trees file to save to

Value

nothing

Author(s)

Richèl J.C. Bilderbeek

See Also

Use parse_beast_log to read a BEAST2 .log file


tracerer documentation built on March 2, 2026, 5:07 p.m.